#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MEIGHT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MEIGHT_HPP_INCLUDED

#include <boost/simd/constant/include/constants/meight.hpp>

#endif
